@@ -329,7 +329,7 @@ async sub getUserConfig {
         };
     }
     return {
-        userInfo => await $self->user->userInfo,
+        userInfo => await $self->config->promisify($self->user->userInfo),
         plugins => \@plugins,
     };
 }
@@ -454,10 +454,10 @@ async sub handleUpload {
 
     my $return;
     try {
-        $return = await $obj->processData({
+        $return = await $self->config->promisify($obj->processData({
             key => $self->req->param('key'),
             formData => $form,
-        });
+        }));
     } catch ($error) {
         if (blessed $error){
             if ($error->isa('CallBackery::Exception')){
@@ -472,7 +472,7 @@ async sub handleUpload {
 
     }
     $self->render_later;
-    return await $self->render(json=>shift);
+    return $self->render(json=>shift);
 }
 
 =head2 handleDownload
@@ -503,7 +503,7 @@ a L<Mojo::Asset>. eg C<Mojo::Asset::File->new(path => '/etc/passwd')>.
 async sub handleDownload {
     my $self = shift;
 
-    if (not await $self->user->isUserAuthenticated){
+    if (not $self->user->isUserAuthenticated){
         return $self->render(json=>{exception=>{
             message=>trm('Access Denied'),code=>3928}});
     }
@@ -527,10 +527,10 @@ async sub handleDownload {
     }
     my $map;
     try {
-        $map = await $obj->processData({
+        $map = await $self->config->promisify($obj->processData({
             key => $key,
             formData => $form,
-        });
+        }));
     } catch ($error) {
         if (blessed $error){
             if ($error->isa('CallBackery::Exception')){
